==> haskell-contravariant-1.5.2-9-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-contravariant.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 contravariant
version:              1.5.2
visibility:           public
id:                   contravariant-1.5.2-9cUYDQvrBi493NpHNvxLum
key:                  contravariant-1.5.2-9cUYDQvrBi493NpHNvxLum
license:              BSD-3-Clause
copyright:            Copyright (C) 2007-2015 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/contravariant/
synopsis:             Contravariant functors
description:          Contravariant functors.
category:             Control, Data
abi:                  83f2a4b401bedcca0ac31b02b830998c
exposed:              True
exposed-modules:
    Data.Functor.Contravariant.Compose
    Data.Functor.Contravariant.Divisible
    Data.Functor.Contravariant.Generic

import-dirs:          /usr/lib/ghc-8.10.3/site-local/contravariant-1.5.2
library-dirs:         /usr/lib/ghc-8.10.3/site-local/contravariant-1.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/contravariant-1.5.2
hs-libraries:         HScontravariant-1.5.2-9cUYDQvrBi493NpHNvxLum
depends:
    StateVar-1.2-67vyH0wM7JT1vFTf2tRTVx base-4.14.1.0
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-contravariant/html/contravariant.haddock

haddock-html:         /usr/share/doc/haskell-contravariant/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-contravariant-1.5.3-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-contravariant.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 contravariant
version:              1.5.3
visibility:           public
id:                   contravariant-1.5.3-7koBfVZf7s8G3BlROnwJJd
key:                  contravariant-1.5.3-7koBfVZf7s8G3BlROnwJJd
license:              BSD-3-Clause
copyright:            Copyright (C) 2007-2015 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/contravariant/
synopsis:             Contravariant functors
description:          Contravariant functors.
category:             Control, Data
abi:                  c0cad65c11966843287c0b609d01f132
exposed:              True
exposed-modules:
    Data.Functor.Contravariant.Compose
    Data.Functor.Contravariant.Divisible
    Data.Functor.Contravariant.Generic

import-dirs:          /usr/lib/ghc-8.10.3/site-local/contravariant-1.5.3
library-dirs:         /usr/lib/ghc-8.10.3/site-local/contravariant-1.5.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/contravariant-1.5.3
hs-libraries:         HScontravariant-1.5.3-7koBfVZf7s8G3BlROnwJJd
depends:
    StateVar-1.2.1-7vo3tV8mPssJqOV48TU4OF base-4.14.1.0
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-contravariant/html/contravariant.haddock

haddock-html:         /usr/share/doc/haskell-contravariant/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
